import 'package:flutter/material.dart';

//Tipos de animaciones
enum AnimationType { normal, fadeIn }
//Main class
class RouteTransition {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransition({
    @required this.context,
    @required this.child,
    this.replacement = false,
    this.animation = AnimationType.normal,
    this.duration = const Duration(milliseconds: 300),
  }) {
    switch (this.animation) {
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeinTransition();
        break;
    }
  }
  //push replace de la pagina
  void _pushReplacementPage(Route widget) =>
      Navigator.pushReplacement(this.context, widget);
  //push normal de la pagina
  void _pushPage(Route widget) => Navigator.push(this.context, widget);

  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => this.child);
    (this.replacement)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }

  void _fadeinTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => this.child,
        transitionDuration: this.duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            child: child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });
    (this.replacement)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }
}
